searchNodes=[{"type":"module","title":"IExHistory2","doc":"Saves shell history and variable bindings between shell sessions. Allows the user to display history, and re-issue historic commands, made much easier since the variable bindings are saved. IExHistory2 can be enabled in ~/.iex.exs for example: Code . append_path ( &quot;~/github/iex_history2/_build/dev/lib/iex_history2/ebin&quot; ) IExHistory2 . initialize ( history_limit : 200 , scope : :local , show_date : true , colors : [ index : :red ] ) The application can, of course, be added as a dependency to mix.exs Functions iex&gt; hl ( ) - list the entire history . iex&gt; hl ( val ) - list ` val ` entries from the start if val is positive , or from the end if negative . iex&gt; hl ( start , stop ) - list entries between ` start ` and ` stop ` . iex&gt; hs ( string ) - list entries that match all or part of the query string . iex&gt; hsi ( string ) - case insensitive list entries that match all or part of the query string . iex&gt; hsa ( string ) - closest match list of entries , e . g &quot;acr.to_str&quot; == &quot;Macro.to_string&quot; iex&gt; hx ( pos ) - execute the expression at position ` pos ` . iex&gt; hc ( pos ) - copy the expression at position pos to the shell . iex&gt; he ( pos ) - edit the expression in a text editor . iex&gt; hb ( ) - show the current bindings . iex&gt; hi ( ) - summary NOTE: To use he/1 the environment variable VISUAL must be set to point to the editor: export VISUAL = &quot;vim&quot; Special Functions iex&gt; IExHistory2 . add_binding ( var , val ) iex&gt; IExHistory2 . get_binding ( var ) iex&gt; IExHistory2 . clear_history ( ) iex&gt; IExHistory2 . clear_bindings ( ) The functions IExHistory2.add_binding/2 and IExHistory2.get_binding/1 allows variables to be set in a module that is invoked in the shell to be accessible in the shell. Navigation The application uses a different set of keys for navigation, and attempts to present multi-line terms and other items as a single line: ctrl ^ u - move up through history . ctrl ^ k - move down through history . ctrl ^ e - allows the currently displayed item to be modified . ctrl ^ w - opens the currently displayed item in an editor . ctrl ^ [ - reset navigation , returns to the prompt . Configuration The following options can be set: [ scope : :local , history_limit : :infinity , hide_history_commands : true , prepend_identifiers : true , command_display_width : int , save_invalid_results : false , key_buffer_history : true , show_date : true , save_bindings : true , colors : [ index : :red , date : :green , command : :yellow , label : :red , variable : :green ] ] :hide_history_commands This will prevent all calls to IExHistory2.* from been saved. :save_invalid_results If set to false, the default, commands that were evaluated incorrectly will not be saved. :key_buffer_history If set to true will allow the user to scroll up (ctrl+u) or down (ctrl+k) through history. Unlike the standard up/down arrow history this is command based not line based. So pasting of a large term or source code will only require 1 up or down key. This mechanism also saves commands that were not properly evaluated; however there is a buffer limit of 150 lines, although this can be changed by updating @history_buffer_size in events_server.ex . This will also not duplicate back to back identical commands. :prepend_identifiers If this is enabled it will prepend identifiers when a call to x = hx(val) is issued. For example: enabled : iex&gt; time = Time . utc_now ( ) . second 14 iex&gt; new_time = hx ( 1 ) 22 iex&gt; new_time 22 # New time is assigned to variable time iex&gt; time 13 # However, the original date variable is unchanged iex&gt; hl ( ) 1 : 2021 - 09 - 01 17 : 13 : 13 : time = Time . utc_now ( ) . second 2 : 2021 - 09 - 01 17 : 13 : 22 : new_time = time = Time . utc_now ( ) . second # We see the binding to new_time disabled : iex&gt; time = Time . utc_now ( ) . second 43 iex&gt; new_time = hx ( 1 ) 50 iex&gt; new_time # New time is assigned to variable time 50 iex&gt; time 50 # However, this time the original time variable has also changed iex&gt; hl ( ) 1 : 2021 - 09 - 01 17 : 17 : 43 : time = Time . utc_now ( ) . second 2 : 2021 - 09 - 01 17 : 17 : 50 : time = Time . utc_now ( ) . second # We do not see the binding to new_time scope can be one of :local, :global or a node name If scope is :local (the default) history will be active on all shells, even those that are remotely connected, but the history for each shell will be unique If scope is node() (e.g. :mgr@localhost ) history will only be active on that shell If scope is :global history will be shared between all shells. However the saving of variable bindings will be disabled along with the date/time in history Furthermore, if a scope of :global is selected following kernel option must be set, either directly as VM options or via an environment variable: export ERL_AFLAGS = &quot;-kernel shell_history enabled&quot; -- erl &quot;-kernel shell_history enabled&quot;","ref":"IExHistory2.html"},{"type":"function","title":"IExHistory2.add_binding/2","doc":"This helper function can be used when testing code (for example a module pasted into the shell). It allows a variable to be set that will become available in the shell. For example: defmodule VarTest do def set_me ( var ) do var = var * 2 IExHistory2 . add_binding ( :test_var , var ) var + 100 end end iex&gt; VarTest . set_me ( 7 ) iex&gt; test_var 14 The variable can be represented as an atom or string.","ref":"IExHistory2.html#add_binding/2"},{"type":"function","title":"IExHistory2.add_binding/3","doc":"Experimental. Same as add_binding/2 , but name is the registered name of a shell pid. See register/1","ref":"IExHistory2.html#add_binding/3"},{"type":"function","title":"IExHistory2.clear/0","doc":"Clears the history and bindings. If scope is :global the IEx session needs restarting for the changes to take effect.","ref":"IExHistory2.html#clear/0"},{"type":"function","title":"IExHistory2.clear_bindings/0","doc":"Clears the bindings.","ref":"IExHistory2.html#clear_bindings/0"},{"type":"function","title":"IExHistory2.clear_history/1","doc":"Clears the history only. If scope is :global the IEx session needs restarting for the changes to take effect. If a value is passed it will clear that many history entries from start, otherwise the entire history is cleared.","ref":"IExHistory2.html#clear_history/1"},{"type":"function","title":"IExHistory2.configuration/0","doc":"Displays the current configuration.","ref":"IExHistory2.html#configuration/0"},{"type":"function","title":"IExHistory2.configure/2","doc":"Allows the following options to be changed, but not saved: :show_date :history_limit :hide_history_commands , :prepend_identifiers , :save_bindings , :command_display_width , :save_invalid_results , :key_buffer_history , :colors Examples: IExHistory2 . configure ( :colors , [ index : :blue ] ) IExHistory2 . configure ( :prepend_identifiers , true )","ref":"IExHistory2.html#configure/2"},{"type":"function","title":"IExHistory2.default_config/0","doc":"Displays the default configuration.","ref":"IExHistory2.html#default_config/0"},{"type":"function","title":"IExHistory2.get_binding/1","doc":"This helper function can be used when testing code (for example a module pasted into the shell). It allows a variable that is set in the shell to be available in a module under test. For example: defmodule VarTest do def get_me ( val ) do if IExHistory2 . get_binding ( :path_to_use ) == :path1 do val + 100 else val + 200 end end end iex&gt; path_to_use = :path1 :path1 iex&gt; VarTest . get_me ( 50 ) 150 iex&gt; path_to_use = :path2 :path2 iex&gt; VarTest . get_me ( 50 ) 250 The variable can be represented as an atom or string.","ref":"IExHistory2.html#get_binding/1"},{"type":"function","title":"IExHistory2.get_binding/2","doc":"Experimental. Same as get_binding/2 , but name is the registered name of a shell pid. See register/1","ref":"IExHistory2.html#get_binding/2"},{"type":"function","title":"IExHistory2.get_bindings/0","doc":"Returns the current shell bindings.","ref":"IExHistory2.html#get_bindings/0"},{"type":"function","title":"IExHistory2.hb/0","doc":"Show the variable bindings.","ref":"IExHistory2.html#hb/0"},{"type":"function","title":"IExHistory2.hc/1","doc":"Copies the command at index 'i' and pastes it to the shell.","ref":"IExHistory2.html#hc/1"},{"type":"function","title":"IExHistory2.he/1","doc":"","ref":"IExHistory2.html#he/1"},{"type":"function","title":"IExHistory2.hi/0","doc":"Show history information summary.","ref":"IExHistory2.html#hi/0"},{"type":"function","title":"IExHistory2.hl/0","doc":"Displays the entire history.","ref":"IExHistory2.html#hl/0"},{"type":"function","title":"IExHistory2.hl/1","doc":"Displays the entire history from the most recent entry back (negative number), or from the oldest entry forward (positive number)","ref":"IExHistory2.html#hl/1"},{"type":"function","title":"IExHistory2.hl/2","doc":"Specify a range, the atoms :start and :stop can also be used.","ref":"IExHistory2.html#hl/2"},{"type":"function","title":"IExHistory2.hs/1","doc":"Returns the list of expressions where all or part of the string matches. The original expression does not need to be a string.","ref":"IExHistory2.html#hs/1"},{"type":"function","title":"IExHistory2.hsa/2","doc":"Like hsa/1 a case insensitive search, but also adds a closeness element to the search. It uses a combination of Myers Difference and Jaro Distance to get close to a match. The estimated closeness is indicated in the result with a default range of &gt; 80%. This can be set by the user. For large histories this command may take several seconds. The original expression does not need to be a string.","ref":"IExHistory2.html#hsa/2"},{"type":"function","title":"IExHistory2.hsi/1","doc":"A case insensitive search the list of expressions where all or part of the string matches. The original expression does not need to be a string.","ref":"IExHistory2.html#hsi/1"},{"type":"function","title":"IExHistory2.hx/1","doc":"Invokes the command at index 'i'.","ref":"IExHistory2.html#hx/1"},{"type":"function","title":"IExHistory2.initialize/1","doc":"Initializes the IExHistory2 app. Takes the following parameters: [ scope : :local , history_limit : :infinity , hide_history_commands : true , prepend_identifiers : true , key_buffer_history : true , command_display_width : :int , save_invalid_results : false , show_date : true , import : true , save_bindings : true , colors : [ index : :red , date : :green , command : :yellow , label : :red , variable : :green ] ] Alternatively a filename can be given that was saved with IExHistory2.save_config() scope can be one of :local, :global or a node() name","ref":"IExHistory2.html#initialize/1"},{"type":"function","title":"IExHistory2.is_enabled?/0","doc":"Returns true or false depending on if history is enabled.","ref":"IExHistory2.html#is_enabled?/0"},{"type":"function","title":"IExHistory2.load_config/1","doc":"Loads the current configuration to file IExHistory2.save_config() . NOTE: Not all options can be set during run-time. Instead pass the filename as a single argument to IExHistory2.initialize()","ref":"IExHistory2.html#load_config/1"},{"type":"function","title":"IExHistory2.register/1","doc":"Registers the shell under the name provided.","ref":"IExHistory2.html#register/1"},{"type":"function","title":"IExHistory2.save_config/1","doc":"Saves the current configuration to file.","ref":"IExHistory2.html#save_config/1"},{"type":"function","title":"IExHistory2.state/0","doc":"Displays the current state: IExHistory2 version 2.0 is enabled : Current history is 199 commands in size . Current bindings are 153 variables in size .","ref":"IExHistory2.html#state/0"},{"type":"function","title":"IExHistory2.stop_clear/0","doc":"Clears the history and bindings then stops the service. If scope is :global the IEx session needs restarting for the changes to take effect.","ref":"IExHistory2.html#stop_clear/0"},{"type":"function","title":"IExHistory2.unbind/1","doc":"Unbinds a variable or list of variables (specify variables as atoms, e.g. foo becomes :foo).","ref":"IExHistory2.html#unbind/1"}]